@@ -28,7 +28,7 @@
 #include "view.h"
 #include "modules/modules.h"
 
-char *fontopia_ver = "1.4";
+char *fontopia_ver = "1.6";
 
 char *font_file_name = (char *)NULL;
 FILE *font_file = NULL;
@@ -104,6 +104,8 @@ void init(int argc, char **argv)
   getScreenSize();
   if(!SCREEN_H || !SCREEN_W)
   {
+    restoreTerminal(); 
+    setScreenColors(WHITE, BGDEFAULT);
     printf("Error: Failed to get terminal size\n");
     exit(1);
   }
@@ -131,6 +133,8 @@ void init(int argc, char **argv)
   if(total_height > SCREEN_H-2 ||
      total_width  > SCREEN_W-3)
   {
+    restoreTerminal(); 
+    setScreenColors(WHITE, BGDEFAULT);
     printf("Error: Terminal size is too small. Required size is at least 80x25\n");
     exit(1);
   }
@@ -175,6 +179,7 @@ void quit(struct font_s *font)
     if(res == ABORT) return;
     if(res == NO) exit_gracefully();
   }
+  buffer_mode_on = 0;
   res = check_font_saved(font, 0);
   if(res == 0) exit_gracefully();
   return;
