@@ -395,6 +395,7 @@ save_only:
       fclose(save);
       free(file_name2);
       if(res) goto error;
+      status_msg("Saved into buffer");
       goto ret;
     }
     /* write to original file */
@@ -404,6 +405,7 @@ save_only:
     fclose(save);
     if(res) goto error;
   }
+  //else if(buffer_mode_on) goto save_only;
   hideCursor();
   return 0;
 
