@@ -51,19 +51,28 @@ void handle_hw_change(struct font_s *font, int old_height, int old_width, int ol
     
     int i = 0;
     int i2 = 0;
+    unsigned int base_o1 = 1 << (old_width-1);
+    if(old_width < 8) base_o1 <<= (8-old_width);
+    else if(old_width > 8 && old_width < 16) base_o1 <<= (16-old_width);
+    else if(old_width > 16 && old_width < 32) base_o1 <<= (32-old_width);
+    unsigned int base_o2 = 1 << (font->width-1);
+    if(font->width < 8) base_o2 <<= (8-font->width);
+    else if(font->width > 8 && font->width < 16) base_o2 <<= (16-font->width);
+    else if(font->width > 16 && font->width < 32) base_o2 <<= (32-font->width);
+
     while(i < font->data_size)
     {
       int j = 0;
       int j2 = 0;
       while(j < old_charsize)
       {
-	int line = (int)(font->data[i+j]);
-	if(old_width > 8 && old_width <= 16) line |= (int)(font->data[i+j+1]) << 8;
-	else if(old_width <= 24) line |= (int)(font->data[i+j+2]) << 16;
-	else if(old_width <= 32) line |= (int)(font->data[i+j+3]) << 24;
-	int line2 = 0;
-	int o1 = 1 << (old_width-1);
-	int o2 = 1 << (font->width-1);
+	unsigned int line = (unsigned int)(font->data[i+j]);
+	if(old_width > 8) line |= (unsigned int)(font->data[i+j+1]) << 8;
+	if(old_width > 16) line |= (unsigned int)(font->data[i+j+2]) << 16;
+	if(old_width > 24) line |= (unsigned int)(font->data[i+j+3]) << 24;
+	unsigned int line2 = 0;
+	unsigned int o1 = base_o1;
+	unsigned int o2 = base_o2;
 	int k = 0;
 	while(k < font->width)
 	{
@@ -89,9 +98,9 @@ void handle_hw_change(struct font_s *font, int old_height, int old_width, int ol
 	  }
 	}
 	newdata[i2+j2] = (char)(line2 & 0xFF);
-	if(font->width > 8 && font->width <= 16) newdata[i2+j2+1] = (char)((line2 >> 8) & 0xFF);
-	else if(font->width <= 24) newdata[i2+j2+2] = (char)((line2 >> 16) & 0xFF);
-	else if(font->width <= 32) newdata[i2+j2+3] = (char)((line2 >> 24) & 0xFF);
+	if(font->width > 8) newdata[i2+j2+1] = (char)((line2 >> 8) & 0xFF);
+	if(font->width > 16) newdata[i2+j2+2] = (char)((line2 >> 16) & 0xFF);
+	if(font->width > 24) newdata[i2+j2+3] = (char)((line2 >> 24) & 0xFF);
 	
 	if(hskip)	/* shriking */
 	{
@@ -104,9 +113,9 @@ void handle_hw_change(struct font_s *font, int old_height, int old_width, int ol
 	  while(rh--)
 	  {
 	    newdata[i2+j2] = (char)(line2 & 0xFF);
-	    if(font->width > 8 && font->width <= 16) newdata[i2+j2+1] = (char)((line2 >> 8) & 0xFF);
-	    else if(font->width <= 24) newdata[i2+j2+2] = (char)((line2 >> 16) & 0xFF);
-	    else if(font->width <= 32) newdata[i2+j2+3] = (char)((line2 >> 24) & 0xFF);
+	    if(font->width > 8) newdata[i2+j2+1] = (char)((line2 >> 8) & 0xFF);
+	    if(font->width > 16) newdata[i2+j2+2] = (char)((line2 >> 16) & 0xFF);
+	    if(font->width > 24) newdata[i2+j2+3] = (char)((line2 >> 24) & 0xFF);
 	    j2 += new_bytes;
 	  }
 	  j += old_bytes;
@@ -589,6 +598,29 @@ skip:
     font->version = old_version;
     return 1;
   }
+
+  /* check for uneven metrics */
+  int rh = (old_height > font->height) ? old_height%font->height :
+                                         font->height%old_height;
+  int rw = (old_width > font->width) ? old_width%font->width :
+                                       font->width%old_width;
+  if(rh || rw)
+  {
+      int m = msgBox("Ratio between old and new metrics\n"
+                     "is uneven. Some of the glyphs may appear\n"
+                     "skewed or distorted. Continue?", YES|NO, CONFIRM);
+      if(m == NO)
+      {
+          /* restore old settings */
+          font->height = old_height;
+          font->width = old_width;
+          font->charsize = old_charsize;
+          font->length = old_length;
+          font->has_unicode_table = old_has_unicode_table;
+          font->version = old_version;
+          return 1;
+      }
+  }
   
   unsigned char tmp_has_unicode_table = font->has_unicode_table;
   unsigned char tmp_ver = font->version;
