@@ -573,13 +573,28 @@ int bdf_write_to_file(FILE *file, struct font_s *font)
   int res;
   struct metadata_item_s *meta = (struct metadata_item_s *)font->metadata;
   res = fprintf(file, "STARTFONT 2.1\n");
-  res = fprintf(file, "FONT %s\n", meta[METADATA_FONT].value2 ? : "");
+  if(meta[METADATA_FONT].value2 && meta[METADATA_FONT].value2[0] != '\0')
+  {
+      res = fprintf(file, "FONT %s\n", meta[METADATA_FONT].value2);
+  }
+  else
+  {
+      char *name = strrchr(font_file_name, '/');
+      if(name) name++;
+      else name = font_file_name;
+      char *dot = strrchr(name, '.');
+      if(dot)
+          res = fprintf(file, "FONT %.*s\n", (int)(dot-name), name);
+      else
+          res = fprintf(file, "FONT %s\n", name);
+  }
   res = fprintf(file, "SIZE 16 75 75\n");
   res = fprintf(file, "FONTBOUNDINGBOX %d %d %d %d\n", meta[METADATA_FONTBOUNDINGBOX_X].value,
 						       meta[METADATA_FONTBOUNDINGBOX_Y].value,
 						       meta[METADATA_FONTBOUNDINGBOX_XOFF].value,
 						       meta[METADATA_FONTBOUNDINGBOX_YOFF].value);
-  res = fprintf(file, "STARTPROPERTIES 12\n");
+  /* NOTE: change this number if we added more properties */
+  res = fprintf(file, "STARTPROPERTIES 23\n");
   res = fprintf(file, "COPYRIGHT \"%s\"\n", meta[METADATA_COPYRIGHT].value2 ? : "");
   res = fprintf(file, "FONT_TYPE \"%s\"\n", meta[METADATA_FONT_TYPE].value2 ? : "");
   res = fprintf(file, "FONT_VERSION \"%s\"\n", meta[METADATA_FONT_VERSION].value2 ? : "");
