@@ -732,7 +732,7 @@ void cp_handle_unicode_table_change(struct font_s *font, char old_has_unicode_ta
 }
 
 
-int show_cp_selection_dialog()
+int show_cp_selection_dialog(int first_selection)
 {
   int h = 12;
   int w = 32;
@@ -742,9 +742,17 @@ int show_cp_selection_dialog()
   if(w > SCREEN_W) w = SCREEN_W-1;
   else y = (SCREEN_W-w)/2;
   
+  if(first_selection < 0) first_selection = 0;
+  if(first_selection >= cp_files_original_ones) first_selection = cp_files_original_ones-1;
+  
+  int vis_entries = h-1;
   int selected_entry = 0;
   int first_vis_entry = 0;
-  int vis_entries = h-1;
+  if(first_selection >= vis_entries-1)
+  {
+      selected_entry = vis_entries-1;
+      first_vis_entry = first_selection-selected_entry;
+  }
   
 draw_win:
   drawBox(x, y, h+x, w+y," - Select codepage - ", YES);
@@ -791,6 +799,8 @@ draw_win:
       case(SPACE_KEY):
 	return first_vis_entry+selected_entry;
 	break;
+      case(ESC_KEY):
+          return -1;
     }
   }
 }
@@ -804,7 +814,10 @@ void cp_change_codepage(struct font_s *font)
     return;
   }
   struct cp_header *hdr = (struct cp_header *)font->file_hdr;
-  short codepage = cp_ids[show_cp_selection_dialog()];
+  int index = show_cp_selection_dialog(hdr->entry_hdr.codepage);
+  /* user cancelled */
+  if(index == -1) return;
+  short codepage = cp_ids[index];
   hdr->entry_hdr.codepage = codepage;
   cp_kill_unitab(font);
   font->has_unicode_table = 1;
@@ -832,7 +845,7 @@ void cp_handle_version_change(struct font_s *font, char old_version)
   hdr->entry_hdr.device_name[5] = ' ';
   hdr->entry_hdr.device_name[6] = ' ';
   hdr->entry_hdr.device_name[7] = ' ';
-  short codepage = cp_ids[show_cp_selection_dialog()];
+  short codepage = cp_ids[show_cp_selection_dialog(0)];
   hdr->entry_hdr.codepage = codepage;
   hdr->entry_hdr.res[0] = 0;
   hdr->entry_hdr.res[1] = 0;
