@@ -150,6 +150,17 @@ int psf_write_to_file(FILE *file, struct font_s *font)
 	res = fputc(font->data[i  ], file);
       }
     }
+    else if(font->width <= 32)
+    {
+      int i;
+      for(i = 0; i < font->data_size; i += 4)
+      {
+	res = fputc(font->data[i+3], file);
+	res = fputc(font->data[i+2], file);
+	res = fputc(font->data[i+1], file);
+	res = fputc(font->data[i  ], file);
+      }
+    }
   }
   /* 3- write unicode table */
   if(font->has_unicode_table)
@@ -376,6 +387,19 @@ struct font_s *psf_load_font(unsigned char *file_data, long file_size)
 	      font->data[i+1] = c;
 	    }
 	  }
+	  else if(font->width <= 32)
+	  {
+	    int i;
+	    for(i = 0; i < font->data_size; i += 4)
+	    {
+	      unsigned char c = font->data[i];
+	      font->data[i] = font->data[i+3];
+	      font->data[i+3] = c;
+              c = font->data[i+1];
+	      font->data[i+1] = font->data[i+2];
+	      font->data[i+2] = c;
+	    }
+	  }
 	}
 	
 	if(font->has_unicode_table)
